# Property

The Property commands are used to create and manage reinforcements and to assign properties to a part.
(See also Material commands and Section commands.) The Property commands are methods of a Part object.

## Create properties for Part

```{eval-rst}
.. autoclass:: abaqus.Property.PropertyPart.PropertyPart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Property.CompositeLayup.CompositeLayup
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.CompositePly.CompositePly
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.CompositePlyArray.CompositePlyArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.MaterialOrientation.MaterialOrientation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.MaterialOrientationArray.MaterialOrientationArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.PlyStackPlot.PlyStackPlot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.PropertyAssembly.PropertyAssembly
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.SectionAssignment.SectionAssignment
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Property.SectionAssignmentArray.SectionAssignmentArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
